function [HH,HL,LH]=coef_dcov2D(pflt)
%[HH,HL,LH]=coef_dcov2D(pflt)
%
%  This function returns diagonal blocks of the covariance matrix 
%  corresponding to 5 levels of 2-dimensional multiwavelet transform 
%  with preprocessing. For details see [SW].
%
%  Input:                                               
%    pflt       string of characters, name of transform used to generate 
%               the covariance matrix; for admissible names see below 
%
%  Output:                                                  
%    HH         r^2 by 5*r^2 real array, diagonal blocks of the high-high part
%               (high-pass filtering in both directions) of the covariance 
%               matrix; r is the number of scaling functions;
%               blocks in HH are organized as follows:HH=[HH1 HH2 ... HH5], 
%               HHk corresponds to the k-th level of the transform 
%    HL         r^2 by 5*r^2 real array, diagonal blocks of the high-low part 
%               (low-pass horizontal and high-pass vertical filtering) 
%               of the covariance matrix; r is the number of scaling functions;
%               blocks in HL are organized as follows: HL=[HL1 HL2 ... HL5], 
%               HLk corresponds to the k-th level of the transform 
%    LH         r^2 by 5*r^2 real array, diagonal blocks of the high-low part 
%               (high-pass horizontal and low-pass vertical filtering) 
%               of the covariance matrix; r is the number of scaling functions;
%               blocks in LH are organized as follows: LH=[LH1 LH2 ... LH5], 
%               LHk corresponds to the k-th level of the transform 
%
%  Admissible Names of the Transforms:
%  (names of wavelet transforms are from coef.m, 
%   names of prefilters are from coef_prep.m) 
%   'ghmap'     'ghm' multiwavelet transform with 'ghmap' prefilter  
%   'ghmorap'   'ghm' multiwavelet transform with 'ghmorap' prefilter
%   'ghmrr'     'ghm' multiwavelet transform with oversampled preprocessing
%   'clap'      'cl' multiwavelet transform with 'clap' prefilter 
%   'clrr'      'cl' multiwavelet transform with oversampled  preprocessing 
%   'bih5ap'    'bih52s' multiwavelet transform with 'bih5ap' prefilter        
%   'bih52srr'  'bih52s' multiwavelet transform with oversampled preprocessing
%   'sa4ap'     'sa4' multiwavelet transform with 'sa4ap' prefilter 
%   'bi9'       'bi9' wavelet transform without preprocessing
%
%  Example of Usage:
%   [HH,HL,LH]=coef_dcov2D('bih52sap')                

% Author: Vasily Strela
% COPYRIGHT 1997,98 by Vasily Strela

if strcmp(pflt,'ghmap')
  HH=[   3.1651876e-01   0.0000000e+00   0.0000000e+00   0.0000000e+00   1.1109160e+00   0.0000000e+00   0.0000000e+00   0.0000000e+00   1.8273632e+00   0.0000000e+00   0.0000000e+00   0.0000000e+00   2.2061161e+00   0.0000000e+00   0.0000000e+00   0.0000000e+00   2.3292864e+00   0.0000000e+00   0.0000000e+00   0.0000000e+00
   0.0000000e+00   3.8611238e-01   0.0000000e+00   0.0000000e+00   0.0000000e+00   1.3012684e+00   0.0000000e+00   0.0000000e+00   0.0000000e+00   1.9184746e+00   0.0000000e+00   0.0000000e+00   0.0000000e+00   2.2395353e+00   0.0000000e+00   0.0000000e+00   0.0000000e+00   2.3382910e+00   0.0000000e+00   0.0000000e+00
   0.0000000e+00   0.0000000e+00   3.8611238e-01   0.0000000e+00   0.0000000e+00   0.0000000e+00   1.3012684e+00   0.0000000e+00   0.0000000e+00   0.0000000e+00   1.9184746e+00   0.0000000e+00   0.0000000e+00   0.0000000e+00   2.2395353e+00   0.0000000e+00   0.0000000e+00   0.0000000e+00   2.3382910e+00   0.0000000e+00
   0.0000000e+00   0.0000000e+00   0.0000000e+00   4.7100769e-01   0.0000000e+00   0.0000000e+00   0.0000000e+00   1.5242372e+00   0.0000000e+00   0.0000000e+00   0.0000000e+00   2.0141286e+00   0.0000000e+00   0.0000000e+00   0.0000000e+00   2.2734608e+00   0.0000000e+00   0.0000000e+00   0.0000000e+00   2.3473304e+00];
  HL=[   7.6355369e-01   7.2446437e-02   0.0000000e+00   0.0000000e+00   1.5388861e+00   5.5783251e-02   0.0000000e+00   0.0000000e+00   2.0550199e+00   2.0980846e-02   0.0000000e+00   0.0000000e+00   2.2804442e+00   6.4230886e-03   0.0000000e+00   0.0000000e+00   2.3505417e+00   1.6919509e-03   0.0000000e+00   0.0000000e+00
   7.2446437e-02   6.9628343e-01   0.0000000e+00   0.0000000e+00   5.5783251e-02   1.5188212e+00   0.0000000e+00   0.0000000e+00   2.0980846e-02   2.0423369e+00   0.0000000e+00   0.0000000e+00   6.4230886e-03   2.2779038e+00   0.0000000e+00   0.0000000e+00   1.6919509e-03   2.3496387e+00   0.0000000e+00   0.0000000e+00
   0.0000000e+00   0.0000000e+00   9.3143778e-01   8.8375382e-02   0.0000000e+00   0.0000000e+00   1.8025700e+00   6.5341557e-02   0.0000000e+00   0.0000000e+00   2.1574820e+00   2.2026940e-02   0.0000000e+00   0.0000000e+00   2.3149894e+00   6.5203884e-03   0.0000000e+00   0.0000000e+00   2.3596285e+00   1.6984917e-03
   0.0000000e+00   0.0000000e+00   8.8375382e-02   8.4937668e-01   0.0000000e+00   0.0000000e+00   6.5341557e-02   1.7790670e+00   0.0000000e+00   0.0000000e+00   2.2026940e-02   2.1441666e+00   0.0000000e+00   0.0000000e+00   6.5203884e-03   2.3124105e+00   0.0000000e+00   0.0000000e+00   1.6984917e-03   2.3587220e+00];
  LH=[   7.6355369e-01   0.0000000e+00   7.2446437e-02   0.0000000e+00   1.5388861e+00   0.0000000e+00   5.5783251e-02   0.0000000e+00   2.0550199e+00   0.0000000e+00   2.0980846e-02   0.0000000e+00   2.2804442e+00   0.0000000e+00   6.4230886e-03   0.0000000e+00   2.3505417e+00   0.0000000e+00   1.6919509e-03   0.0000000e+00
   0.0000000e+00   9.3143778e-01   0.0000000e+00   8.8375382e-02   0.0000000e+00   1.8025700e+00   0.0000000e+00   6.5341557e-02   0.0000000e+00   2.1574820e+00   0.0000000e+00   2.2026940e-02   0.0000000e+00   2.3149894e+00   0.0000000e+00   6.5203884e-03   0.0000000e+00   2.3596285e+00   0.0000000e+00   1.6984917e-03
   7.2446437e-02   0.0000000e+00   6.9628343e-01   0.0000000e+00   5.5783251e-02   0.0000000e+00   1.5188212e+00   0.0000000e+00   2.0980846e-02   0.0000000e+00   2.0423369e+00   0.0000000e+00   6.4230886e-03   0.0000000e+00   2.2779038e+00   0.0000000e+00   1.6919509e-03   0.0000000e+00   2.3496387e+00   0.0000000e+00
   0.0000000e+00   8.8375382e-02   0.0000000e+00   8.4937668e-01   0.0000000e+00   6.5341557e-02   0.0000000e+00   1.7790670e+00   0.0000000e+00   2.2026940e-02   0.0000000e+00   2.1441666e+00   0.0000000e+00   6.5203884e-03   0.0000000e+00   2.3124105e+00   0.0000000e+00   1.6984917e-03   0.0000000e+00   2.3587220e+00];

elseif strcmp(pflt,'sa4ap')
 A=diag(ones(1,4));
 HH=[A A A A A];
 HL=HH;
 LH=HH;

elseif strcmp(pflt,'ghmrr')
  HH=[   1.8225000e-02   1.4316750e-02   1.4316750e-02   1.1246603e-02   4.0214622e-01  -6.7219900e-03  -6.7219900e-03   1.1236000e-04   1.5940325e+00   1.3256775e-03   1.3256775e-03   1.1025000e-06   2.0730240e+00  -1.4398000e-04  -1.4398000e-04   1.0000000e-08   2.2049280e+00   0.0000000e+00   0.0000000e+00   0.0000000e+00
   1.4316750e-02   9.0450000e-02   1.1246603e-02   7.1053500e-02  -6.7219900e-03   6.1785235e-01   1.1236000e-04  -1.0327580e-02   1.3256775e-03   1.7118284e+00   1.1025000e-06   1.4236425e-03  -1.4398000e-04   2.1070753e+00   1.0000000e-08  -1.4634500e-04   0.0000000e+00   2.2137632e+00   0.0000000e+00   0.0000000e+00
   1.4316750e-02   1.1246603e-02   9.0450000e-02   7.1053500e-02  -6.7219900e-03   1.1236000e-04   6.1785235e-01  -1.0327580e-02   1.3256775e-03   1.1025000e-06   1.7118284e+00   1.4236425e-03  -1.4398000e-04   1.0000000e-08   2.1070753e+00  -1.4634500e-04   0.0000000e+00   0.0000000e+00   2.2137632e+00   0.0000000e+00
   1.1246603e-02   7.1053500e-02   7.1053500e-02   4.4890000e-01   1.1236000e-04  -1.0327580e-02  -1.0327580e-02   9.4926049e-01   1.1025000e-06   1.4236425e-03   1.4236425e-03   1.8383292e+00   1.0000000e-08  -1.4634500e-04  -1.4634500e-04   2.1416859e+00   0.0000000e+00   0.0000000e+00   0.0000000e+00   2.2226337e+00];
  HL=[   1.5660000e-01   2.7683230e-02   1.2301800e-01   2.1746716e-02   8.9186856e-01   4.4213400e-02  -1.4907840e-02  -7.3903972e-04   1.8638470e+00   2.0751259e-02   1.5500688e-03   1.7257790e-05   2.1511335e+00   6.1083097e-03  -1.4940502e-04  -4.2424710e-07   2.2251405e+00   1.5571145e-03   0.0000000e+00   0.0000000e+00
   2.7683230e-02   1.3972500e-01   2.1746716e-02   1.0976175e-01   4.4213400e-02   8.7205137e-01  -7.3903972e-04  -1.4576590e-02   2.0751259e-02   1.8539833e+00   1.7257790e-05   1.5418657e-03   6.1083097e-03   2.1483214e+00  -4.2424710e-07  -1.4920971e-04   1.5571145e-03   2.2244154e+00   0.0000000e+00   0.0000000e+00
   1.2301800e-01   2.1746716e-02   7.7720000e-01   1.3739085e-01  -1.4907840e-02  -7.3903972e-04   1.3702555e+00   6.7928906e-02   1.5500688e-03   1.7257790e-05   2.0015817e+00   2.2284737e-02  -1.4940502e-04  -4.2424710e-07   2.1864678e+00   6.2086442e-03   0.0000000e+00   0.0000000e+00   2.2340566e+00   1.5633539e-03
   2.1746716e-02   1.0976175e-01   1.3739085e-01   6.9345000e-01  -7.3903972e-04  -1.4576590e-02   6.7928906e-02   1.3398086e+00   1.7257790e-05   1.5418657e-03   2.2284737e-02   1.9909891e+00  -4.2424710e-07  -1.4920971e-04   6.2086442e-03   2.1836095e+00   0.0000000e+00   0.0000000e+00   1.5633539e-03   2.2333287e+00];
  LH=[   1.5660000e-01   1.2301800e-01   2.7683230e-02   2.1746716e-02   8.9186856e-01  -1.4907840e-02   4.4213400e-02  -7.3903972e-04   1.8638470e+00   1.5500688e-03   2.0751259e-02   1.7257790e-05   2.1511335e+00  -1.4940502e-04   6.1083097e-03  -4.2424710e-07   2.2251405e+00   0.0000000e+00   1.5571145e-03   0.0000000e+00
   1.2301800e-01   7.7720000e-01   2.1746716e-02   1.3739085e-01  -1.4907840e-02   1.3702555e+00  -7.3903972e-04   6.7928906e-02   1.5500688e-03   2.0015817e+00   1.7257790e-05   2.2284737e-02  -1.4940502e-04   2.1864678e+00  -4.2424710e-07   6.2086442e-03   0.0000000e+00   2.2340566e+00   0.0000000e+00   1.5633539e-03
   2.7683230e-02   2.1746716e-02   1.3972500e-01   1.0976175e-01   4.4213400e-02  -7.3903972e-04   8.7205137e-01  -1.4576590e-02   2.0751259e-02   1.7257790e-05   1.8539833e+00   1.5418657e-03   6.1083097e-03  -4.2424710e-07   2.1483214e+00  -1.4920971e-04   1.5571145e-03   0.0000000e+00   2.2244154e+00   0.0000000e+00
   2.1746716e-02   1.3739085e-01   1.0976175e-01   6.9345000e-01  -7.3903972e-04   6.7928906e-02  -1.4576590e-02   1.3398086e+00   1.7257790e-05   2.2284737e-02   1.5418657e-03   1.9909891e+00  -4.2424710e-07   6.2086442e-03  -1.4920971e-04   2.1836095e+00   0.0000000e+00   1.5633539e-03   0.0000000e+00   2.2333287e+00];

elseif strcmp(pflt,'clap')
  HH=[   1.7265960e-02  -0.0000000e+00  -0.0000000e+00   0.0000000e+00   1.9824640e-02   0.0000000e+00   0.0000000e+00   0.0000000e+00   1.6409610e-02   0.0000000e+00   0.0000000e+00   0.0000000e+00   1.5976960e-02   0.0000000e+00   0.0000000e+00   0.0000000e+00   1.5700090e-02   0.0000000e+00   0.0000000e+00   0.0000000e+00
  -0.0000000e+00   1.9565460e-02   0.0000000e+00  -0.0000000e+00   0.0000000e+00   2.0458240e-02   0.0000000e+00   0.0000000e+00   0.0000000e+00   1.6717050e-02   0.0000000e+00   0.0000000e+00   0.0000000e+00   1.6065440e-02   0.0000000e+00   0.0000000e+00   0.0000000e+00   1.5737680e-02   0.0000000e+00   0.0000000e+00
  -0.0000000e+00   0.0000000e+00   1.9565460e-02  -0.0000000e+00   0.0000000e+00   0.0000000e+00   2.0458240e-02   0.0000000e+00   0.0000000e+00   0.0000000e+00   1.6717050e-02   0.0000000e+00   0.0000000e+00   0.0000000e+00   1.6065440e-02   0.0000000e+00   0.0000000e+00   0.0000000e+00   1.5737680e-02   0.0000000e+00
   0.0000000e+00  -0.0000000e+00  -0.0000000e+00   2.2171210e-02   0.0000000e+00   0.0000000e+00   0.0000000e+00   2.1112090e-02   0.0000000e+00   0.0000000e+00   0.0000000e+00   1.7030250e-02   0.0000000e+00   0.0000000e+00   0.0000000e+00   1.6154410e-02   0.0000000e+00   0.0000000e+00   0.0000000e+00   1.5775360e-02];
  HL=[   1.7261758e-02   0.0000000e+00  -0.0000000e+00  -0.0000000e+00   1.7735445e-02   0.0000000e+00   0.0000000e+00   0.0000000e+00   1.6080100e-02   1.1110904e-19   0.0000000e+00   0.0000000e+00   1.5813825e-02   1.0963452e-19   0.0000000e+00   0.0000000e+00   1.5667568e-02   3.2604128e-19   0.0000000e+00   0.0000000e+00
   0.0000000e+00   1.8307705e-02  -0.0000000e+00  -0.0000000e+00   0.0000000e+00   1.8215857e-02   0.0000000e+00   0.0000000e+00   1.1110904e-19   1.6203841e-02   0.0000000e+00   0.0000000e+00   1.0963452e-19   1.5853292e-02   0.0000000e+00   0.0000000e+00   3.2604128e-19   1.5678255e-02   0.0000000e+00   0.0000000e+00
  -0.0000000e+00  -0.0000000e+00   1.9560698e-02   0.0000000e+00   0.0000000e+00   0.0000000e+00   1.8302274e-02   0.0000000e+00   0.0000000e+00   0.0000000e+00   1.6381366e-02   1.1319071e-19   0.0000000e+00   0.0000000e+00   1.5901401e-02   1.1024168e-19   0.0000000e+00   0.0000000e+00   1.5705081e-02   3.2682190e-19
  -0.0000000e+00  -0.0000000e+00   0.0000000e+00   2.0745946e-02   0.0000000e+00   0.0000000e+00   0.0000000e+00   1.8798040e-02   0.0000000e+00   0.0000000e+00   1.1319071e-19   1.6507426e-02   0.0000000e+00   0.0000000e+00   1.1024168e-19   1.5941087e-02   0.0000000e+00   0.0000000e+00   3.2682190e-19   1.5715793e-02];
  LH=[   1.7261758e-02  -0.0000000e+00   0.0000000e+00  -0.0000000e+00   1.7735445e-02   0.0000000e+00   0.0000000e+00   0.0000000e+00   1.6080100e-02   0.0000000e+00   1.1110904e-19   0.0000000e+00   1.5813825e-02   0.0000000e+00   1.0963452e-19   0.0000000e+00   1.5667568e-02   0.0000000e+00   3.2604128e-19   0.0000000e+00
  -0.0000000e+00   1.9560698e-02  -0.0000000e+00   0.0000000e+00   0.0000000e+00   1.8302274e-02   0.0000000e+00   0.0000000e+00   0.0000000e+00   1.6381366e-02   0.0000000e+00   1.1319071e-19   0.0000000e+00   1.5901401e-02   0.0000000e+00   1.1024168e-19   0.0000000e+00   1.5705081e-02   0.0000000e+00   3.2682190e-19
   0.0000000e+00  -0.0000000e+00   1.8307705e-02  -0.0000000e+00   0.0000000e+00   0.0000000e+00   1.8215857e-02   0.0000000e+00   1.1110904e-19   0.0000000e+00   1.6203841e-02   0.0000000e+00   1.0963452e-19   0.0000000e+00   1.5853292e-02   0.0000000e+00   3.2604128e-19   0.0000000e+00   1.5678255e-02   0.0000000e+00
  -0.0000000e+00   0.0000000e+00  -0.0000000e+00   2.0745946e-02   0.0000000e+00   0.0000000e+00   0.0000000e+00   1.8798040e-02   0.0000000e+00   1.1319071e-19   0.0000000e+00   1.6507426e-02   0.0000000e+00   1.1024168e-19   0.0000000e+00   1.5941087e-02   0.0000000e+00   3.2682190e-19   0.0000000e+00   1.5715793e-02];

elseif strcmp(pflt,'clrr') 
  HH=[   5.6250000e-01   0.0000000e+00   0.0000000e+00   0.0000000e+00   1.4554225e-01   0.0000000e+00   0.0000000e+00   0.0000000e+00   7.7123524e-01   0.0000000e+00   0.0000000e+00   0.0000000e+00   8.9094721e-01   0.0000000e+00   0.0000000e+00   0.0000000e+00   9.7397161e-01   0.0000000e+00   0.0000000e+00   0.0000000e+00
   0.0000000e+00   4.6875000e-02   0.0000000e+00   0.0000000e+00   0.0000000e+00   7.7444500e-02   0.0000000e+00   0.0000000e+00   0.0000000e+00   6.8692804e-01   0.0000000e+00   0.0000000e+00   0.0000000e+00   8.6668898e-01   0.0000000e+00   0.0000000e+00   0.0000000e+00   9.6518820e-01   0.0000000e+00   0.0000000e+00
   0.0000000e+00   0.0000000e+00   4.6875000e-02   0.0000000e+00   0.0000000e+00   0.0000000e+00   7.7444500e-02   0.0000000e+00   0.0000000e+00   0.0000000e+00   6.8692804e-01   0.0000000e+00   0.0000000e+00   0.0000000e+00   8.6668898e-01   0.0000000e+00   0.0000000e+00   0.0000000e+00   9.6518820e-01   0.0000000e+00
   0.0000000e+00   0.0000000e+00   0.0000000e+00   3.9062500e-03   0.0000000e+00   0.0000000e+00   0.0000000e+00   4.1209000e-02   0.0000000e+00   0.0000000e+00   0.0000000e+00   6.1183684e-01   0.0000000e+00   0.0000000e+00   0.0000000e+00   8.4309124e-01   0.0000000e+00   0.0000000e+00   0.0000000e+00   9.5648400e-01];
  HL=[   5.6250000e-01   0.0000000e+00   0.0000000e+00   0.0000000e+00   3.6709245e-01   0.0000000e+00   0.0000000e+00   0.0000000e+00   8.6000616e-01   0.0000000e+00   0.0000000e+00   0.0000000e+00   9.3984709e-01   4.5028651e-18   0.0000000e+00   0.0000000e+00   9.8533278e-01  -1.4938191e-17   0.0000000e+00  -0.0000000e+00
   0.0000000e+00   3.2812500e-01   0.0000000e+00   0.0000000e+00   0.0000000e+00   3.1599007e-01   0.0000000e+00   0.0000000e+00   0.0000000e+00   8.2670231e-01   0.0000000e+00   0.0000000e+00   4.5028651e-18   9.2827659e-01   0.0000000e+00   0.0000000e+00  -1.4938191e-17   9.8202824e-01  -0.0000000e+00   0.0000000e+00
   0.0000000e+00   0.0000000e+00   4.6875000e-02   0.0000000e+00   0.0000000e+00   0.0000000e+00   1.9533359e-01   0.0000000e+00   0.0000000e+00   0.0000000e+00   7.6599501e-01   0.0000000e+00   0.0000000e+00   0.0000000e+00   9.1425744e-01   4.3802635e-18   0.0000000e+00  -0.0000000e+00   9.7644692e-01  -1.4803476e-17
   0.0000000e+00   0.0000000e+00   0.0000000e+00   2.7343750e-02   0.0000000e+00   0.0000000e+00   0.0000000e+00   1.6814150e-01   0.0000000e+00   0.0000000e+00   0.0000000e+00   7.3633176e-01   0.0000000e+00   0.0000000e+00   4.3802635e-18   9.0300197e-01  -0.0000000e+00   0.0000000e+00  -1.4803476e-17   9.7317218e-01];
  LH=[   5.6250000e-01   0.0000000e+00   0.0000000e+00   0.0000000e+00   3.6709245e-01   0.0000000e+00   0.0000000e+00   0.0000000e+00   8.6000616e-01   0.0000000e+00   0.0000000e+00   0.0000000e+00   9.3984709e-01   0.0000000e+00   4.5028651e-18   0.0000000e+00   9.8533278e-01   0.0000000e+00  -1.4938191e-17  -0.0000000e+00
   0.0000000e+00   4.6875000e-02   0.0000000e+00   0.0000000e+00   0.0000000e+00   1.9533359e-01   0.0000000e+00   0.0000000e+00   0.0000000e+00   7.6599501e-01   0.0000000e+00   0.0000000e+00   0.0000000e+00   9.1425744e-01   0.0000000e+00   4.3802635e-18   0.0000000e+00   9.7644692e-01  -0.0000000e+00  -1.4803476e-17
   0.0000000e+00   0.0000000e+00   3.2812500e-01   0.0000000e+00   0.0000000e+00   0.0000000e+00   3.1599007e-01   0.0000000e+00   0.0000000e+00   0.0000000e+00   8.2670231e-01   0.0000000e+00   4.5028651e-18   0.0000000e+00   9.2827659e-01   0.0000000e+00  -1.4938191e-17  -0.0000000e+00   9.8202824e-01   0.0000000e+00
   0.0000000e+00   0.0000000e+00   0.0000000e+00   2.7343750e-02   0.0000000e+00   0.0000000e+00   0.0000000e+00   1.6814150e-01   0.0000000e+00   0.0000000e+00   0.0000000e+00   7.3633176e-01   0.0000000e+00   4.3802635e-18   0.0000000e+00   9.0300197e-01  -0.0000000e+00  -1.4803476e-17   0.0000000e+00   9.7317218e-01];

elseif strcmp(pflt,'bih5ap')
  HH=[   2.9920900e-03   0.0000000e+00   0.0000000e+00   0.0000000e+00   4.1209000e-02   0.0000000e+00   0.0000000e+00   0.0000000e+00   1.0407076e-01   0.0000000e+00   0.0000000e+00   0.0000000e+00   1.4630625e-01   0.0000000e+00   0.0000000e+00   0.0000000e+00   1.6459249e-01   0.0000000e+00   0.0000000e+00   0.0000000e+00
   0.0000000e+00   1.6344360e-02   0.0000000e+00   0.0000000e+00   0.0000000e+00   3.1893330e-01   0.0000000e+00   0.0000000e+00   0.0000000e+00   8.3156602e-01   0.0000000e+00   0.0000000e+00   0.0000000e+00   1.1599695e+00   0.0000000e+00   0.0000000e+00   0.0000000e+00   1.2977937e+00   0.0000000e+00   0.0000000e+00
   0.0000000e+00   0.0000000e+00   1.6344360e-02   0.0000000e+00   0.0000000e+00   0.0000000e+00   3.1893330e-01   0.0000000e+00   0.0000000e+00   0.0000000e+00   8.3156602e-01   0.0000000e+00   0.0000000e+00   0.0000000e+00   1.1599695e+00   0.0000000e+00   0.0000000e+00   0.0000000e+00   1.2977937e+00   0.0000000e+00
   0.0000000e+00   0.0000000e+00   0.0000000e+00   8.9281440e-02   0.0000000e+00   0.0000000e+00   0.0000000e+00   2.4683552e+00   0.0000000e+00   0.0000000e+00   0.0000000e+00   6.6445373e+00   0.0000000e+00   0.0000000e+00   0.0000000e+00   9.1966628e+00   0.0000000e+00   0.0000000e+00   0.0000000e+00   1.0232961e+01];
  HL=[   1.1284344e-02   0.0000000e+00   0.0000000e+00   0.0000000e+00   5.5516317e-02  -1.6903146e-17   0.0000000e+00  -0.0000000e+00   1.0048587e-01   1.1192436e-18   0.0000000e+00   0.0000000e+00   1.2516022e-01   1.2607103e-17   0.0000000e+00   0.0000000e+00   1.3498224e-01  -1.6450795e-17   0.0000000e+00  -0.0000000e+00
   0.0000000e+00   4.2848293e-01   0.0000000e+00   0.0000000e+00  -1.6903146e-17   2.4977314e+00  -0.0000000e+00   0.0000000e+00   1.1192436e-18   4.6193656e+00   0.0000000e+00   0.0000000e+00   1.2607103e-17   5.7587346e+00   0.0000000e+00   0.0000000e+00  -1.6450795e-17   6.2085242e+00  -0.0000000e+00   0.0000000e+00
   0.0000000e+00   0.0000000e+00   6.1640987e-02   0.0000000e+00   0.0000000e+00  -0.0000000e+00   4.2966347e-01  -1.3082035e-16   0.0000000e+00   0.0000000e+00   8.0292136e-01   8.9431934e-18   0.0000000e+00   0.0000000e+00   9.9231606e-01   9.9953726e-17   0.0000000e+00  -0.0000000e+00   1.0643201e+00  -1.2971271e-16
   0.0000000e+00   0.0000000e+00   0.0000000e+00   2.3405978e+00  -0.0000000e+00   0.0000000e+00  -1.3082035e-16   1.9330964e+01   0.0000000e+00   0.0000000e+00   8.9431934e-18   3.6910535e+01   0.0000000e+00   0.0000000e+00   9.9953726e-17   4.5657356e+01  -0.0000000e+00   0.0000000e+00  -1.2971271e-16   4.8953533e+01];
  LH=[   1.1284344e-02   0.0000000e+00   0.0000000e+00   0.0000000e+00   5.5516317e-02   0.0000000e+00  -1.6903146e-17  -0.0000000e+00   1.0048587e-01   0.0000000e+00   1.1192436e-18   0.0000000e+00   1.2516022e-01   0.0000000e+00   1.2607103e-17   0.0000000e+00   1.3498224e-01   0.0000000e+00  -1.6450795e-17  -0.0000000e+00
   0.0000000e+00   6.1640987e-02   0.0000000e+00   0.0000000e+00   0.0000000e+00   4.2966347e-01  -0.0000000e+00  -1.3082035e-16   0.0000000e+00   8.0292136e-01   0.0000000e+00   8.9431934e-18   0.0000000e+00   9.9231606e-01   0.0000000e+00   9.9953726e-17   0.0000000e+00   1.0643201e+00  -0.0000000e+00  -1.2971271e-16
   0.0000000e+00   0.0000000e+00   4.2848293e-01   0.0000000e+00  -1.6903146e-17  -0.0000000e+00   2.4977314e+00   0.0000000e+00   1.1192436e-18   0.0000000e+00   4.6193656e+00   0.0000000e+00   1.2607103e-17   0.0000000e+00   5.7587346e+00   0.0000000e+00  -1.6450795e-17  -0.0000000e+00   6.2085242e+00   0.0000000e+00
   0.0000000e+00   0.0000000e+00   0.0000000e+00   2.3405978e+00  -0.0000000e+00  -1.3082035e-16   0.0000000e+00   1.9330964e+01   0.0000000e+00   8.9431934e-18   0.0000000e+00   3.6910535e+01   0.0000000e+00   9.9953726e-17   0.0000000e+00   4.5657356e+01  -0.0000000e+00  -1.2971271e-16   0.0000000e+00   4.8953533e+01];

elseif strcmp(pflt,'bih52srr')
  HH=[   3.5156250e-02   0.0000000e+00   0.0000000e+00   0.0000000e+00   1.0074276e-01   0.0000000e+00   0.0000000e+00   0.0000000e+00   3.2703106e+00   0.0000000e+00   0.0000000e+00   0.0000000e+00   7.5630500e+00   0.0000000e+00   0.0000000e+00   0.0000000e+00   9.8690223e+00   0.0000000e+00   0.0000000e+00   0.0000000e+00
   0.0000000e+00   2.6362500e-02   0.0000000e+00   0.0000000e+00   0.0000000e+00   2.6566380e-01   0.0000000e+00   0.0000000e+00   0.0000000e+00   2.6572449e+01   0.0000000e+00   0.0000000e+00   0.0000000e+00   6.0688107e+01   0.0000000e+00   0.0000000e+00   0.0000000e+00   7.8118424e+01   0.0000000e+00   0.0000000e+00
   0.0000000e+00   0.0000000e+00   2.6362500e-02   0.0000000e+00   0.0000000e+00   0.0000000e+00   2.6566380e-01   0.0000000e+00   0.0000000e+00   0.0000000e+00   2.6572449e+01   0.0000000e+00   0.0000000e+00   0.0000000e+00   6.0688107e+01   0.0000000e+00   0.0000000e+00   0.0000000e+00   7.8118424e+01   0.0000000e+00
   0.0000000e+00   0.0000000e+00   0.0000000e+00   1.9768360e-02   0.0000000e+00   0.0000000e+00   0.0000000e+00   7.0056900e-01   0.0000000e+00   0.0000000e+00   0.0000000e+00   2.1591070e+02   0.0000000e+00   0.0000000e+00   0.0000000e+00   4.8697897e+02   0.0000000e+00   0.0000000e+00   0.0000000e+00   6.1834780e+02];
  HL=[   1.9000906e-01   0.0000000e+00   0.0000000e+00   0.0000000e+00   5.4224308e-01   0.0000000e+00   0.0000000e+00   0.0000000e+00   4.1270688e+00   4.0154546e-16   0.0000000e+00   0.0000000e+00   6.9982712e+00   0.0000000e+00   0.0000000e+00   0.0000000e+00   8.2885111e+00  -4.6458128e-16   0.0000000e+00  -0.0000000e+00
   0.0000000e+00   1.9173555e+00   0.0000000e+00   0.0000000e+00   0.0000000e+00   2.2889660e+01   0.0000000e+00   0.0000000e+00   4.0154546e-16   1.8956979e+02   0.0000000e+00   0.0000000e+00   0.0000000e+00   3.2241862e+02   0.0000000e+00   0.0000000e+00  -4.6458128e-16   3.8127748e+02  -0.0000000e+00   0.0000000e+00
   0.0000000e+00   0.0000000e+00   1.4248146e-01   0.0000000e+00   0.0000000e+00   0.0000000e+00   1.4299227e+00   0.0000000e+00   0.0000000e+00   0.0000000e+00   3.3533917e+01   3.2627012e-15   0.0000000e+00   0.0000000e+00   5.6156158e+01   0.0000000e+00   0.0000000e+00  -0.0000000e+00   6.5607859e+01  -3.6774015e-15
   0.0000000e+00   0.0000000e+00   0.0000000e+00   1.4377610e+00   0.0000000e+00   0.0000000e+00   0.0000000e+00   6.0361203e+01   0.0000000e+00   0.0000000e+00   3.2627012e-15   1.5403227e+03   0.0000000e+00   0.0000000e+00   0.0000000e+00   2.5871805e+03  -0.0000000e+00   0.0000000e+00  -3.6774015e-15   3.0180088e+03];
  LH=[   1.9000906e-01   0.0000000e+00   0.0000000e+00   0.0000000e+00   5.4224308e-01   0.0000000e+00   0.0000000e+00   0.0000000e+00   4.1270688e+00   0.0000000e+00   4.0154546e-16   0.0000000e+00   6.9982712e+00   0.0000000e+00   0.0000000e+00   0.0000000e+00   8.2885111e+00   0.0000000e+00  -4.6458128e-16  -0.0000000e+00
   0.0000000e+00   1.4248146e-01   0.0000000e+00   0.0000000e+00   0.0000000e+00   1.4299227e+00   0.0000000e+00   0.0000000e+00   0.0000000e+00   3.3533917e+01   0.0000000e+00   3.2627012e-15   0.0000000e+00   5.6156158e+01   0.0000000e+00   0.0000000e+00   0.0000000e+00   6.5607859e+01  -0.0000000e+00  -3.6774015e-15
   0.0000000e+00   0.0000000e+00   1.9173555e+00   0.0000000e+00   0.0000000e+00   0.0000000e+00   2.2889660e+01   0.0000000e+00   4.0154546e-16   0.0000000e+00   1.8956979e+02   0.0000000e+00   0.0000000e+00   0.0000000e+00   3.2241862e+02   0.0000000e+00  -4.6458128e-16  -0.0000000e+00   3.8127748e+02   0.0000000e+00
   0.0000000e+00   0.0000000e+00   0.0000000e+00   1.4377610e+00   0.0000000e+00   0.0000000e+00   0.0000000e+00   6.0361203e+01   0.0000000e+00   3.2627012e-15   0.0000000e+00   1.5403227e+03   0.0000000e+00   0.0000000e+00   0.0000000e+00   2.5871805e+03  -0.0000000e+00  -3.6774015e-15   0.0000000e+00   3.0180088e+03];

elseif strcmp(pflt,'sa4ap')
 A=diag(ones(1,4));
 HH=[A A A A A];
 HL=HH;
 LH=HH;

elseif strcmp(pflt,'bi9')
  HH=[0.9663    1.2513    1.0906    1.0074    0.9803];
  HL=[1.0227    1.1117    1.0139    0.9669    0.9517];
  LH=[1.0227    1.1117    1.0139    0.9669    0.9517];

end
